%global pypi_name websockets

%ifarch %{ix86} x86_64
%bcond_without tests
%endif

Name:           python-%{pypi_name}
Version:        14.1
Release:        %mkrel 2
Summary:        Implementation of the WebSocket Protocol for Python
Group:          Development/Python
License:        BSD
URL:            https://github.com/aaugustin/websockets
Source0:        %{url}/archive/%{version}/%{pypi_name}-%{version}.tar.gz
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
%if %{with tests}
BuildRequires:  python3dist(pytest)
%endif

%description
websockets is a library for developing WebSocket servers and clients in
Python. It implements RFC 6455 with a focus on correctness and simplicity. It
passes the Autobahn Testsuite.

Built on top of Python’s asynchronous I/O support introduced in PEP 3156, it
provides an API based on coroutines, making it easy to write highly concurrent
applications.

%package -n     python3-%{pypi_name}
Summary:        Implementation of the WebSocket Protocol for Python3
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
websockets is a library for developing WebSocket servers and clients in
Python. It implements RFC 6455 with a focus on correctness and simplicity. It
passes the Autobahn Testsuite.

Built on top of Python’s asynchronous I/O support introduced in PEP 3156, it
provides an API based on coroutines, making it easy to write highly concurrent
applications.

%prep
%autosetup -n %{pypi_name}-%{version} -p1

%generate_buildrequires
%pyproject_buildrequires %{?with_tests:-t}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files websockets

%check
%if %{with tests}
%pytest -v --ignore compliance --ignore tests/sync -k "not test_explicit_host_port and not test_server_shuts_down and not test_keepalive_is_enabled and not test_close_waits and not test_close_server_keeps_handlers_running"
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.rst


%changelog
* Sat Mar 01 2025 daviddavid <daviddavid> 14.1-2.mga10
+ Revision: 2154439
- rebuild for python 3.13

* Sun Jan 19 2025 daviddavid <daviddavid> 14.1-1.mga10
+ Revision: 2139849
- new version: 14.1

* Sat Sep 28 2024 daviddavid <daviddavid> 13.0.1-1.mga10
+ Revision: 2101702
- new version: 13.0.1

* Wed Dec 20 2023 tv <tv> 12.0-2.mga10
+ Revision: 2020305
- Rebuild for python 3.12
+ wally <wally>
- new version 12.0

* Sun Jan 15 2023 guillomovitch <guillomovitch> 10.4-1.mga9
+ Revision: 1933173
- new version 10.4

* Thu Sep 08 2022 neoclust <neoclust> 10.3-1.mga9
+ Revision: 1885753
- New version  10.3

* Sat Mar 19 2022 umeabot <umeabot> 8.1-4.mga9
+ Revision: 1799174
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 8.1-3.mga9
+ Revision: 1778572
- Rebuild for python-3.10

* Tue Mar 23 2021 daviddavid <daviddavid> 8.1-2.mga9
+ Revision: 1708066
- rebuild for python 3.9

* Fri Jan 15 2021 pterjan <pterjan> 8.1-1.mga8
+ Revision: 1671905
- Mageiaize
- imported package python-websockets


* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jul 18 2020 Julien Enselme <jujens@jujens.eu> - 8.1-1
- Update to 8.1

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 8.0.2-5
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 8.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 8.0.2-3
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Wed Aug 21 2019 Miro Hrončok <mhroncok@redhat.com> - 8.0.2-2
- Rebuilt for Python 3.8

* Tue Aug 20 2019 Julien Enselme <jujens@jujens> - 8.0.2-1
- Update to 8.0.2

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 8.0-4
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 8.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Jul 13 2019 Julien Enselme <jujens@jujens.eu> - 8.0-2
- Skip tests because it prevents rebuild for Python 3.8. They fail because tests check the number of deprecation warnings and more are raised on Python 3.8.

* Sat Jul 13 2019 Julien Enselme <jujens@jujens.eu> - 8.0-1
- Update to 8.0

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 20 2018 Julien Enselme <jujens@jujens.eu> - 6.0
- Update to 6.0

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 5.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 5.0.1-2
- Rebuilt for Python 3.7

* Sat Jun 02 2018 Julien Enselme <jujens@jujens.eu> - 5.0.1-1
- Update to 5.0.1

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Nov 06 2017 Julien Enselme <jujens@jujens.eu> - 4.0.1-1
- Update to 4.0.1

* Mon Aug 21 2017 Julien Enselme <jujens@jujens.eu> - 3.4-2
- Remove tests with timeouts

* Mon Aug 21 2017 Julien Enselme <jujens@jujens.eu> - 3.4-1
- Update to 3.4

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Apr 05 2017 Julien Enselme <jujens@jujens.eu> - 3.3-1
- Update to 3.3

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 3.2-3
- Rebuild for Python 3.6

* Sun Sep 18 2016 Julien Enselme <jujens@jujens.eu> - 3.2-2
- Correct tests on Python 3.5.2

* Sun Sep 18 2016 Julien Enselme <jujens@jujens.eu> - 3.2-1
- Update to 3.2

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Jun 21 2016 Julien Enselme <jujens@jujens.eu> - 3.1-1
- Update to 3.1

* Sun Feb 14 2016 Julien Enselme <jujens@jujens.eu> - 3.0-1
- Update to 3.0
- Correct build on rawhide

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Nov 22 2015 Julien Enselme <jujens@jujens.eu> - 2.7-1
- Update to 2.7

* Thu Nov 12 2015 Kalev Lember <klember@redhat.com> - 2.6-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Wed Aug 26 2015 Julien Enselme <jujens@jujens.eu> - 2.6-1
- Initial package
